@@ -27,6 +27,19 @@ def get_entities(seq, suffix=False):
         >>> get_entities(seq)
         [('PER', 0, 1), ('LOC', 3, 3)]
     """
+
+    def _validate_chunk(chunk, suffix):
+        if chunk == 'O':
+            return
+
+        if suffix:
+            if not (chunk.endswith('-B') or chunk.endswith('-I')):
+                raise ValueError('Invalid tag is found: {}'.format(chunk))
+
+        else:
+            if not (chunk.startswith('B-') or chunk.startswith('I-')):
+                raise ValueError('Invalid tag is found: {}'.format(chunk))
+
     # for nested list
     if any(isinstance(s, list) for s in seq):
         seq = [item for sublist in seq for item in sublist + ['O']]
@@ -36,6 +49,8 @@ def get_entities(seq, suffix=False):
     begin_offset = 0
     chunks = []
     for i, chunk in enumerate(seq + ['O']):
+        _validate_chunk(chunk, suffix)
+
         if suffix:
             tag = chunk[-1]
             type_ = chunk.split('-')[0]
@@ -322,7 +337,7 @@ def classification_report(y_true, y_pred, digits=2, suffix=False):
     for e in pred_entities:
         d2[e[0]].add((e[1], e[2]))
 
-    last_line_heading = 'macro avg'
+    last_line_heading = 'weighted avg'
     width = max(name_width, len(last_line_heading), digits)
 
     headers = ["precision", "recall", "f1-score", "support"]
@@ -333,7 +348,8 @@ def classification_report(y_true, y_pred, digits=2, suffix=False):
     row_fmt = u'{:>{width}s} ' + u' {:>9.{digits}f}' * 3 + u' {:>9}\n'
 
     ps, rs, f1s, s = [], [], [], []
-    for type_name, true_entities in d1.items():
+    for type_name in sorted(d1.keys()):
+        true_entities = d1[type_name]
         pred_entities = d2[type_name]
         nb_correct = len(true_entities & pred_entities)
         nb_pred = len(pred_entities)
@@ -359,6 +375,12 @@ def classification_report(y_true, y_pred, digits=2, suffix=False):
                              f1_score(y_true, y_pred, suffix=suffix),
                              np.sum(s),
                              width=width, digits=digits)
+    report += row_fmt.format('macro avg',
+                             np.average(ps),
+                             np.average(rs),
+                             np.average(f1s),
+                             np.sum(s),
+                             width=width, digits=digits)
     report += row_fmt.format(last_line_heading,
                              np.average(ps, weights=s),
                              np.average(rs, weights=s),
